<?php

require_once 'Horde/Form.php';

/**
 * $Horde: hermes/lib/Admin.php,v 1.16 2005/01/03 14:34:55 jan Exp $
 *
 * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */
class AddJobTypeForm extends Horde_Form {

    function AddJobTypeForm(&$vars)
    {
        parent::Horde_Form($vars, 'addjobtypeform');

        $this->addVariable(_("Job Type"), 'name', 'text', true);
    }

}

class EditJobTypeStep1Form extends Horde_Form {

    function EditJobTypeStep1Form(&$vars)
    {
        global $hermes;

        parent::Horde_Form($vars, 'editjobtypestep1form');

        $jobtypes = $hermes->getJobTypes();
        if (count($jobtypes)) {
            $subtype = 'enum';
            $type_params = array($jobtypes);
        } else {
            $subtype = 'invalid';
            $type_params = array(_("There are no job types to edit"));
        }

        $this->addVariable(_("JobType Name"), 'jobtype', $subtype, true, false, null, $type_params);
    }

}

class EditJobTypeStep2Form extends Horde_Form {

    function EditJobTypeStep2Form(&$vars)
    {
        global $hermes;

        parent::Horde_Form($vars, 'editjobtypestep2form');

        $jobtype = $vars->get('jobtype');
        $info = $hermes->getJobType($jobtype);
        if (!$info || is_a($info, 'PEAR_Error')) {
            $stype = 'invalid';
            $type_params = array(_("This is not a valid job type."));
        } else {
            $stype = 'text';
            $type_params = array();
        }

        $this->addHidden('', 'jobtype', 'int', true, true);

        $sname = &$this->addVariable(_("Job Type"), 'name', $stype, true, false, null, $type_params);
        if (!empty($info['name'])) {
            $sname->setDefault($info['name']);
        }

    }

}

class DeleteJobTypeForm extends Horde_Form {

    function DeleteJobTypeForm(&$vars)
    {
        global $hermes;

        parent::Horde_Form($vars, 'deletejobtypeform');

        $jobtype = $vars->get('jobtype');
        $info = $hermes->getJobType($jobtype);

        $yesnotype = 'enum';
        $type_params = array(array(0 => _("No"), 1 => _("Yes")));

        $this->addHidden('', 'jobtype', 'int', true, true);

        $sname = &$this->addVariable(_("Job Type"), 'name', 'text', false, true);
        $sname->setDefault($info['name']);

        $this->addVariable(_("Really delete this job type? This may cause data problems!!"), 'yesno', $yesnotype, true, false, null, $type_params);
    }

}

class EditClientStep1Form extends Horde_Form {

    function EditClientStep1Form(&$vars)
    {
        global $hermes;

        parent::Horde_Form($vars, 'editclientstep1form');

        $clients = Hermes::listClients();
		if (is_a($clients, 'PEAR_Error')) {
			$subtype = 'invalid';
			$type_params = array($clients->getMessage());
		} elseif (count($clients)) {
            $subtype = 'enum';
            $type_params = array($clients);
        } else {
            $subtype = 'invalid';
            $type_params = array(_("There are no clients to edit"));
        }

        $this->addVariable(_("Client Name"), 'client', $subtype, true, false, null, $type_params);
    }

}

class EditClientStep2Form extends Horde_Form {

    function EditClientStep2Form(&$vars)
    {
        global $hermes;

        parent::Horde_Form($vars, 'editclientstep2form');

        $client = $vars->get('client');
        $info = $hermes->getClientSettings($client);
        if (!$info || is_a($info, 'PEAR_Error')) {
            $stype = 'invalid';
            $type_params = array(_("This is not a valid client."));
        } else {
            $stype = 'text';
            $type_params = array();
        }

        $this->addHidden('', 'client', 'text', true, true);
        $name = &$this->addVariable(_("Client"), 'name', $stype, false, true, false, null, $type_params);
        $name->setDefault($info['name']);

        $enterdescription = &$this->addVariable(sprintf(_("Should users enter descriptions of their timeslices for this client? If not, the description will automatically be \"%s\"."), _("See Attached Timesheet")), 'enterdescription', 'boolean', true);
        if (!empty($info['enterdescription'])) {
            $enterdescription->setDefault($info['enterdescription']);
        }

        $exportid = &$this->addVariable(_("ID for this client when exporting data, if different from the name displayed above."), 'exportid', 'text', false);
        if (!empty($info['exportid'])) {
            $exportid->setDefault($info['exportid']);
        }
    }

}
