<?php

require_once 'Horde/Form.php';

/**
 * TimeForm abstract class.
 *
 * Hermes forms can extend this to gain access to shared functionality.
 *
 * $Horde: hermes/lib/TimeForm.php,v 1.34 2005/01/03 14:40:58 eraserhd Exp $
 *
 * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @version $Revision: 1.34 $
 * @package Hermes
 */
class TimeForm extends Horde_Form {

    function TimeForm(&$vars, $name = null)
    {
        parent::Horde_Form($vars, $name);
    }

    function getJobTypeType()
    {
        global $hermes;

        $types = $hermes->getJobTypes();
        if (is_a($types, 'PEAR_Error')) {
            return array('invalid', array(sprintf(_("An error occurred listing job types: %s"),
                                           $types->getMessage())));
        } elseif (count($types)) {
            return array('enum', array($types));
        } else {
            return array('invalid', array(_("There are no job types configured.")));
        }
    }

    function getClientType()
    {
        $clients = Hermes::listClients();
        if (is_a($clients, 'PEAR_Error')) {
            return array('invalid', array(sprintf(_("An error occurred listing clients: %s"),
                                           $clients->getMessage())));
        } elseif (count($clients)) {
            return array('enum', array($clients));
        } else {
            return array('invalid', array(_("There are no clients which you have access to.")));
        }
    }

}

/**
 * TimeEntryForm Class.
 *
 * $Horde: hermes/lib/TimeForm.php,v 1.34 2005/01/03 14:40:58 eraserhd Exp $
 *
 * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @version $Revision: 1.34 $
 * @package Hermes
 */
class TimeEntryForm extends TimeForm {

    function TimeEntryForm(&$vars)
    {
        global $hermes, $conf;

        if ($vars->exists('id')) {
            parent::TimeForm($vars, _("Update Time"));
            $this->setButtons(_("Update my time"));
        } else {
            parent::TimeForm($vars, _("Enter Time"));
            $this->setButtons(_("Enter my time"));
        }

        list($clienttype, $clientparams) = $this->getClientType();
        if ($clienttype == 'enum') {
            $map = array();
            $clients = Hermes::listClients();
            foreach ($clients as $id => $name) {
                $info = $hermes->getClientSettings($id);
                if (!is_a($info, 'PEAR_Error')) {
                    $map[$id] = $info['enterdescription'] ? '' : _("See Attached Timesheet");
                } else {
                    $map[$id] = '';
                }
            }

            require_once 'Horde/Form/Action.php';
            $action = &Horde_Form_Action::factory('conditional_setvalue',
                                                  array('map' => $map,
                                                        'target' => 'description'));
        }

        list($typetype, $typeparams) = $this->getJobTypeType();

        if ($vars->exists('id')) {
            $this->addHidden('', 'id', 'int', true);
        }

        $var = &$this->addVariable(_("Date"), 'date', 'monthdayyear', true,
                                   false, null, array(date('Y') - 1));
        $var->setDefault(date('Y-m-d'));

        $cli = &$this->addVariable(_("Client"), 'client', $clienttype, true, false, null, $clientparams);
        if (isset($action)) {
            $cli->setAction($action);
        }

        $this->addVariable(_("Job Type"), 'type', $typetype, true, false, null, $typeparams);
        $this->addVariable(_("Hours"), 'hours', 'number', true);

        if ($conf['time']['choose_ifbillable']) {
            $yesno = array(1 => _("Yes"), 0 => _("No"));
            $this->addVariable(_("Billable?"), 'billable', 'enum', true, false, null, array($yesno));
        }

        $this->addVariable(_("Description"), 'description', 'longtext', true, false, null, array(4, 60));
        $this->addVariable(_("Additional Notes"), 'note', 'longtext', false, false, null, array(4, 60));
    }

}

/**
 * TimeReviewForm Class.
 *
 * $Horde: hermes/lib/TimeForm.php,v 1.34 2005/01/03 14:40:58 eraserhd Exp $
 *
 * Copyright 2003-2005 Jay 'Eraserhaed' Felice <jfelice@cronosys.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Jay 'Eraserhead' Felice <jfelice@cronosys.com>
 * @version $Revision: 1.34 $
 * @package Hermes
 */
class TimeReviewForm extends TimeForm {

    function TimeReviewForm(&$vars)
    {
        global $hermes, $conf;

        parent::TimeForm($vars, _("Update Submitted Time"));
        $this->setButtons(_("Update time"));

        list($clienttype, $clientparams) = $this->getClientType();
        if ($clienttype == 'enum') {
            $map = array();
            $clients = Hermes::listClients();
            foreach ($clients as $id => $name) {
                $info = $hermes->getClientSettings($id);
                if (!is_a($info, 'PEAR_Error')) {
                    $map[$id] = $info['enterdescription'] ? '' : _("See Attached Timesheet");
                } else {
                    $map[$id] = '';
                }
            }

            require_once 'Horde/Form/Action.php';
            $action = &Horde_Form_Action::factory('conditional_setvalue',
                                                  array('map' => $map,
                                                        'target' => 'description'));
        }

        list($typetype, $typeparams) = $this->getJobTypeType();

        $this->addHidden('', 'id', 'int', true);

        $employees = array();

        require_once 'Horde/Identity.php';
        $auth = &Auth::singleton($conf['auth']['driver']);
        $users = $auth->listUsers();
        if (!is_a($users, 'PEAR_Error')) {
            foreach ($users as $user) {
                $identity = &Identity::singleton('none', $user);
                $employees[$user] = $identity->getValue('fullname');
            }
        }

        $this->addVariable(_("Employee"), 'employee', 'enum', true, false, null, array($employees));

        $var = &$this->addVariable(_("Date"), 'date', 'monthdayyear', true);
        $var->setDefault(date('y-m-d'));


        $cli = &$this->addVariable(_("Client"), 'client', $clienttype, true, false, null, $clientparams);
        if (isset($action)) {
            $cli->setAction($action);
        }

        $this->addVariable(_("Job Type"), 'type', $typetype, true, false, null, $typeparams);
        $this->addVariable(_("Hours"), 'hours', 'number', true);

        if ($conf['time']['choose_ifbillable']) {
            $yesno = array(1 => _("Yes"), 0 => _("No"));
            $this->addVariable(_("Billable?"), 'billable', 'enum', true, false, null, array($yesno));
        }

        $this->addVariable(_("Description"), 'description', 'longtext', true, false, null, array(4, 60));
        $this->addVariable(_("Additional Notes"), 'note', 'longtext', false, false, null, array(4, 60));
    }

}
